@@ -115,12 +115,10 @@ class TempAtoms:
             self.forces = list(atoms.get_forces())
             if isinstance(atoms.calc, RunnerSinglePointCalculator):
                 self.totalcharge = atoms.calc.get_property('totalcharge')
-            else:
-                self.totalcharge = np.sum(atoms.get_initial_charges())
         else:
             self.energy = 0.0
             self.forces = [[0.0, 0.0, 0.0] for i in self.positions]
-            self.totalcharge = 0.0
+            self.totalcharge = np.sum(atoms.get_initial_charges())
 
     def convert(self, input_units: str, output_units: str) -> None:
         """Convert all data from `input_units` to `output_units`."""
