@@ -8,3 +8,5 @@ from .sfvalues import (RunnerSymmetryFunctionValuesPlots,
 from .fitresults import RunnerFitResultsPlots
 from .scaling import RunnerScalingPlots
 from .symmetryfunctions import SymmetryFunctionSetPlots
+from .weights import RunnerWeightsPlots
+from .calculator import RunnerPlots
