@@ -53,7 +53,8 @@ class RunnerPlots(GenericPlots):
         """Show the reference forces in `self.dataset`."""
         if self._forces_reference is None:
             self._forces_reference = np.array([i.get_forces()
-                                               for i in self.dataset])
+                                               for i in self.dataset],
+                                              dtype='object')
 
         return self._forces_reference.copy()
 
@@ -182,8 +183,7 @@ class RunnerPlots(GenericPlots):
             axes = plt.gca()
 
         # Calculate the total force of each atom.
-        n_atoms = int(forces.size / 3)
-        atomic_forces = forces.reshape(n_atoms, 3)
+        atomic_forces = np.vstack(forces)  # type: ignore
         totalforce = np.sqrt(np.sum(atomic_forces**2, axis=1))
 
         if indices is None:
@@ -264,8 +264,7 @@ class RunnerPlots(GenericPlots):
             axes = plt.gca()
 
         # Calculate the total force of each atom.
-        n_atoms = int(forces.size / 3)
-        atomic_forces = forces.reshape(n_atoms, 3)
+        atomic_forces = np.vstack(forces)  # type: ignore
 
         if indices is None:
             indices = np.arange(0, len(atomic_forces), 1)
@@ -457,14 +456,17 @@ class RunnerPlots(GenericPlots):
         if axes is None:
             axes = plt.gca()
 
-        if indices is None:
-            indices = np.arange(0, len(self.forces_reference), 1)
+        force_hdnnp = np.vstack(self.forces_hdnnp)  # type: ignore
+        force_reference = np.vstack(self.forces_reference)  # type: ignore
 
-        force_hdnnp = self.forces_hdnnp[indices]
-        force_reference = self.forces_reference[indices]
+        if indices is None:
+            indices = np.arange(0, len(force_reference), 1)
+
+        force_hdnnp = force_hdnnp[indices, :]
+        force_reference = force_reference[indices, :]
 
         # Calculate the deviation in meV.
-        deviation = (force_hdnnp - force_reference) * 1000
+        deviation = abs(force_hdnnp - force_reference) * 1000
 
         # Use a context manager to apply styles locally.
         with plt.style.context(self.styles):
@@ -508,9 +510,8 @@ class RunnerPlots(GenericPlots):
         forces_reference = self.forces_reference[indices]
 
         # Create atomic arrays.
-        n_atoms = int(forces_reference.size / 3)
-        atomic_forces_hdnnp = forces_hdnnp.reshape(n_atoms, 3)
-        atomic_forces_reference = forces_reference.reshape(n_atoms, 3)
+        atomic_forces_hdnnp = np.vstack(forces_hdnnp)  # type: ignore
+        atomic_forces_reference = np.vstack(forces_reference)  # type: ignore
 
         # Determine the axis limits.
         axes_lim = [min(atomic_forces_hdnnp.min(),
@@ -542,7 +543,7 @@ class RunnerPlots(GenericPlots):
                                atomic_forces_hdnnp[:, 2],
                                label=r'$F_{\mathrm{z}}$')
             ax_scatter.plot(atomic_forces_reference.flatten(),
-                            atomic_forces_hdnnp.flatten(), color='grey')
+                            atomic_forces_reference.flatten(), color='grey')
 
             # Create histograms.
             ax_histx.hist(atomic_forces_reference[:, 0])
@@ -565,4 +566,6 @@ class RunnerPlots(GenericPlots):
             ax_scatter.set_ylabel(r'Predicted Forces $F$ / eV $\AA^{-1}$')
             fig.suptitle('Force Comparison')
 
+            ax_scatter.legend()
+
         return fig
