@@ -296,7 +296,7 @@ class RunnerWeights(ElementStorageMixin):
         element = chemical_symbols[atomic_number]
 
         # Store the weights as a np.ndarray.
-        self.data[element] = np.genfromtxt(infile, usecols=(0))
+        self.data[element] = np.genfromtxt(infile, usecols=(0))  # type: ignore
 
     # For some reason pylint thinks that this function has the same signature as
     # ase.io.storageclasses.write_weights.
@@ -344,7 +344,8 @@ class RunnerWeights(ElementStorageMixin):
             fullpath = os.path.join(path, f'{prefix}.{number:03d}.{suffix}')
 
             # Store the weights as a np.ndarray.
-            self.data[element] = np.genfromtxt(fullpath, usecols=(0))
+            self.data[element] = np.genfromtxt(fullpath,
+                                               usecols=(0))  # type: ignore
 
     def write(
         self,
