@@ -717,7 +717,8 @@ def generate_symmetryfunctions_sftype3(
                 label = '-'.join(pair)
                 radial_etas.append(eta_angular[label])
 
-            eta_list += [np.mean(radial_etas)]
+            mean_eta: float = float(np.mean(radial_etas))
+            eta_list += [mean_eta]
 
         if lambda_angular is None:
             lambda_angular = [-1.0, +1.0]
